[−][src]Struct bytecodec::combinator::TryMap
Combinator which tries to convert decoded values by calling the specified function.
This is created by calling DecodeExt::try_map method.
Methods
impl<D, T, E, F> TryMap<D, T, E, F>[src]
pub fn inner_ref(&self) -> &D[src]
Returns a reference to the inner decoder.
pub fn inner_mut(&mut self) -> &mut D[src]
Returns a mutable reference to the inner decoder.
pub fn into_inner(self) -> D[src]
Takes ownership of this instance and returns the inner decoder.