Struct bytecodec::fixnum::F64leDecoder [−][src]
pub struct F64leDecoder(_);
Decoder which decodes f64 values by little-endian byte order.
Examples
use bytecodec::Decode; use bytecodec::fixnum::F64leDecoder; use bytecodec::io::IoDecodeExt; let mut decoder = F64leDecoder::new(); let item = decoder.decode_exact([119, 190, 159, 26, 47, 221, 94, 64].as_ref()).unwrap(); assert_eq!(item, 123.456);
Methods
impl F64leDecoder[src]
impl F64leDecoderTrait Implementations
impl Debug for F64leDecoder[src]
impl Debug for F64leDecoderfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Default for F64leDecoder[src]
impl Default for F64leDecoderfn default() -> F64leDecoder[src]
fn default() -> F64leDecoderReturns the "default value" for a type. Read more
impl Decode for F64leDecoder[src]
impl Decode for F64leDecodertype Item = f64
The type of items to be decoded.
fn decode(&mut self, buf: &[u8], eos: Eos) -> Result<usize>[src]
fn decode(&mut self, buf: &[u8], eos: Eos) -> Result<usize>Consumes the given buffer (a part of a byte sequence), and proceeds the decoding process. Read more
fn finish_decoding(&mut self) -> Result<Self::Item>[src]
fn finish_decoding(&mut self) -> Result<Self::Item>Finishes the current decoding process and returns the decoded item. Read more
fn requiring_bytes(&self) -> ByteCount[src]
fn requiring_bytes(&self) -> ByteCountReturns the lower bound of the number of bytes needed to decode the next item. Read more
fn is_idle(&self) -> bool[src]
fn is_idle(&self) -> boolReturns true if there are no items to be decoded by the decoder at the next invocation of decode method, otherwise false. Read more